@@ -22,9 +22,11 @@ URL = 'ws://127.0.0.1:8000/ws/client?room=9527'
 
 
 async def async_main():
-    while True:
+    # 加上重试次数限制，防止忘记关闭Notebook内核导致占用资源
+    cnt = 10
+    while cnt > 0:
         await asyncio.sleep(1)
-        logger.info('try to connect')
+        logger.info('try to connect. {}', cnt)
         try:
             # 连接被控端地址（带/client），同时还要指定约定的房间号
             async with WebSocketConnection(URL, token=TOKEN) as conn:
@@ -32,8 +34,9 @@ async def async_main():
                 await conn.reverse()
         except Exception as e:
             logger.info(e)
-            # 重试不能太块，一直在重试时，试着点重启内核
+            # 重试不能太块，一直在重试时，试着点击重启内核
             await asyncio.sleep(5)
+            cnt -= 1
 
 
 if __name__ == '__main__':
